@@ -24,65 +24,7 @@ format.image_entry = function (x, type = "console", ...){
   out
 }
 
-#' @export
-#' @title draw a single bar
-#' @description This function is used to insert bars into flextable with function \code{display}
-#' @param value bar height
-#' @param max max bar height
-#' @param barcol bar color
-#' @param bg background color
-#' @param width,height size of the resulting png file in inches
-#' @importFrom grDevices as.raster col2rgb rgb
-minibar <- function(value, max, barcol = "#CCCCCC", bg = "transparent", width = 1, height = .2) {
-  stopifnot(value >= 0, max >= 0)
-  barcol <- rgb(t(col2rgb(barcol))/255)
-  bg <- ifelse( bg == "transparent", bg, rgb(t(col2rgb(bg))/255) )
-  if( any(value > max) ){
-    warning("value > max, truncate to max")
-    value[value > max] <- max
-  }
-  width_ <- as.integer(width * 72)
-  value <- as.integer( (value / max) * width_ )
-  n_empty <- width_ - value
 
-  src <- sapply(seq_along(value), function(x) tempfile(fileext = ".png") )
-
-  rasters <- mapply(function(count_on, count_off, bg_on, bg_off ){
-    as.raster( matrix(c(rep(bg_on, count_on), rep(bg_off, count_off)), nrow = 1) )
-  }, value, n_empty, bg_on = barcol, bg_off = bg,
-  SIMPLIFY = FALSE )
-  mapply(function(src, raster, width, height){
-    raster_write(x = raster, path = src, width = width*72, height = height*72 )
-  }, src = src, raster = rasters, width = width, height = height,
-  SIMPLIFY = FALSE )
-
-  image_entry(src = src, width = width, height = height)
-}
-
-
-#' @export
-#' @title image wrapper
-#' @description The function has to be used with function display().
-#' It lets add images within flextable.
-#' @param x image will be repeated while iterating this variable. The variable should be
-#' one of the original data frame. Note its values are not used, only its size.
-#' @param src image filename
-#' @param width,height size of the png file in inches
-#' @seealso \code{\link{display}}
-#' @examples
-#' library(officer)
-#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-#' myft <- flextable(head( mtcars, n = 10))
-#' myft <- display(myft,
-#'     i = ~ qsec > 18, col_key = "qsec", pattern = "{{r_logo}}",
-#'     formatters = list( r_logo ~ as_image(qsec,
-#'       src = img.file, width = .20, height = .15)),
-#'     fprops = list(qsec = fp_text(color = "orange")) )
-#' myft
-as_image <- function(x, src, width = 1, height = .2) {
-  image_entry(src = rep(src, length(x)),
-              width = width, height = height)
-}
 
 drop_column <- function(x, cols){
   x[, !(colnames(x) %in% cols), drop = FALSE]
@@ -162,3 +104,64 @@ nrow_part <- function(x, part){
     0
   else nrow(x[[part]]$dataset)
 }
+
+process_url <- function(rel, url, str, pattern, double_esc = TRUE){
+  new_rid <- sprintf("rId%.0f", rel$get_next_id())
+
+  if(double_esc)
+    escape <- function(x) htmlEscape(htmlEscape(x))
+  else escape <- function(x) htmlEscape(x)# it seems that word does not behave as powerpoint
+
+  rel$add(
+    id = new_rid, type = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink",
+    target = escape(url), target_mode = "External" )
+
+  str_replace_all( string = str,
+    fixed( sprintf("<%s r:id=\"%s\"", pattern, url ) ),
+    sprintf("<%s r:id=\"%s\"", pattern, new_rid )
+  )
+}
+
+create_display <- function(data, col_keys){
+  set_formatter_type_formals <- formals(set_formatter_type)
+  formatters <- mapply(function(x, varname){
+    if( is.double(x) ) paste0(varname, " ~ sprintf(", shQuote(set_formatter_type_formals$fmt_double), ", `", varname ,"`)")
+    else if( is.integer(x) ) paste0(varname, " ~ sprintf(", shQuote(set_formatter_type_formals$fmt_integer), ", `", varname ,"`)")
+    else if( is.factor(x) ) paste0(varname, " ~ as.character(`", varname ,"`)")
+    else if( is.character(x) ) paste0(varname, " ~ as.character(`", varname ,"`)")
+    else if( inherits(x, "Date") ) paste0(varname, " ~ format(`", varname ,"`, ", shQuote(set_formatter_type_formals$fmt_date), ")")
+    else if( inherits(x, "POSIXt") ) paste0(varname, " ~ format(`", varname ,"`, ", shQuote(set_formatter_type_formals$fmt_datetime), ")")
+    else paste0(varname, " ~ ", set_formatter_type_formals$fun_any, "(`", varname ,"`)")
+  }, data[col_keys], col_keys, SIMPLIFY = FALSE)
+  formatters <- mapply(function(f, varname){
+    display_parser$new(x = paste0("{{", varname, "}}"),
+                       formatters = list( as.formula( f ) ),
+                       fprops = list() )
+  }, formatters, col_keys )
+  display_structure$new(nrow(data), col_keys, formatters )
+}
+
+
+replace.na <- function(x, by = ""){
+  x[is.na(x)] <- by
+  x
+}
+dbl_fun <- function(x, fmt_double) {
+  replace.na(sprintf(fmt_double, x), by = "")
+}
+int_fun <- function(x, fmt_integer) {
+  replace.na(sprintf(fmt_integer, x), by = "")
+}
+str_fun <- function(x) {
+  replace.na(as.character(x), by = "")
+}
+date_fun <- function(x, fmt_date){
+  replace.na(format(x, fmt_date), by = "")
+}
+datetime_fun <- function(x, fmt_datetime){
+  replace.na(format(x, fmt_datetime), by = "")
+}
+any_fun <- function(x){
+  replace.na(format(x), by = "")
+}
+
